# Welcome to first nbdev tutorial
> simple tutorial to say hello


Proj trial 

## Install

`pip install your_project_name`

## How to use

calling method

```python
say_hello("Neha")
```




    'Hello Neha!'


